==> ndvcpl-9.2.2-en-download.zip: ndvcpl-9.2.2-en/webhelp/ndvcpl-webhelp/navig/contents.js <==
//
//	FindinSite-CD-JS-HelpIndex database naturaldevelopmentserverforzoscomplete
//
//	Copyright (c) 2016-2025 Software AG, Darmstadt, Germany and/or Software AG USA Inc., Reston, VA, USA
//
var naturaldevelopmentserverforzoscomplete = {
    baseurls: ["../"],
    varname: "naturaldevelopmentserverforzoscomplete",
        tree: [
            { url: "about/about.htm", title: "About this Documentation",
              tree: [
                  { url: "about/document_conventions.htm", title: "Document Conventions" },
                  { url: "about/online_information.htm", title: "Online Information and Support" },
                  { url: "about/data_protection.htm", title: "Data Protection" },
              ]
            },
            { url: "ndv/ndv-over.htm", title: "Natural Development Server for z/OS (Com-plete)",
              tree: [
                  { url: "ndv/ndv-intro.htm", title: "Introducing Natural Development Server" },
                  { url: "ndv/ndv-fdev.htm", title: "Development Server File" },
                  { url: "ndv/ndv-natdv.htm", title: "Natural Development Server on Mainframes" },
                  { url: "ndv/ndv-prereq.htm", title: "Prerequisites" },
                  { url: "ndv/ndv-instcpl.htm", title: "Installing the Natural Development Server on z/OS (Com-plete)" },
                  { url: "ndv/ndv-conf.htm", title: "Configuring the Natural Development Server" },
                  { url: "ndv/ndv-operate.htm", title: "Operating the Natural Development Server" },
                  { url: "ndv/ndv-natmopi.htm", title: "Monitor Client NATMOPI" },
                  { url: "ndv/ndv-htmlmon.htm", title: "HTML Monitor Client" },
                  { url: "ndv/ndv-limit.htm", title: "SPoD-Specific Limitations and Considerations" },
                  { url: "ndv/ndv-faq.htm", title: "Natural Development Server Frequently Asked Questions" },
              ]
            },
            { url: "general/legal.htm", title: "Copyright" },
        ]
};

var mainProject = 1;

$.event.trigger({ type: "fishidbloaded", db: naturaldevelopmentserverforzoscomplete });

==> ndvcpl-9.2.4-en-download.zip: ndvcpl-9.2.4-en/webhelp/ndvcpl-webhelp/navig/contents.js <==
//
//	FindinSite-CD-JS-HelpIndex database naturaldevelopmentserverforzoscomplete
//
//	Copyright (c) 2016-2025 Software AG, Darmstadt, Germany and/or Software AG USA Inc., Reston, VA, USA
//
var naturaldevelopmentserverforzoscomplete = {
    baseurls: ["../"],
    varname: "naturaldevelopmentserverforzoscomplete",
        tree: [
            { url: "about/about.htm", title: "About this Documentation",
              tree: [
                  { url: "about/document_conventions.htm", title: "Document Conventions" },
                  { url: "about/online_information.htm", title: "Online Information and Support" },
                  { url: "about/data_protection.htm", title: "Data Protection" },
              ]
            },
            { url: "ndv/ndv-over.htm", title: "Natural Development Server for z/OS (Com-plete)",
              tree: [
                  { url: "ndv/ndv-intro.htm", title: "Introducing Natural Development Server" },
                  { url: "ndv/ndv-fdev.htm", title: "Development Server File" },
                  { url: "ndv/ndv-natdv.htm", title: "Natural Development Server on z/OS" },
                  { url: "ndv/ndv-prereq.htm", title: "Prerequisites" },
                  { url: "ndv/ndv-instcpl.htm", title: "Installing the Natural Development Server on z/OS (Com-plete)" },
                  { url: "ndv/ndv-conf.htm", title: "Configuring the Natural Development Server" },
                  { url: "ndv/ndv-operate.htm", title: "Operating the Natural Development Server" },
                  { url: "ndv/ndv-natmopi.htm", title: "Monitor Client NATMOPI" },
                  { url: "ndv/ndv-htmlmon.htm", title: "HTML Monitor Client" },
                  { url: "ndv/ndv-limit.htm", title: "SPoD-Specific Limitations and Considerations" },
                  { url: "ndv/ndv-faq.htm", title: "Natural Development Server Frequently Asked Questions" },
              ]
            },
            { url: "general/legal.htm", title: "Copyright" },
        ]
};

var mainProject = 1;

$.event.trigger({ type: "fishidbloaded", db: naturaldevelopmentserverforzoscomplete });
